%-------------------------------------------------------------------------%
% EXAMPLE 1: DYNAMIC ANALYSIS OF IDEALIZED CROSS SECTION
%-------------------------------------------------------------------------%
clc; clear all; close all

%% DEFINE INPUT

% 1. Define control parameters
IRES=0; ICOMB=0; IGRAV=0; IRIG=0; PSP=0.0;

% 2. Define material properties
EC=5.76e5; DENSC=4.8e-3; POISC=0.20; DAMPC=0.04; % Dam            
EF=5.76e5; DENSF=5.1e-3;             DAMPF=0.04; % Foundation
ALPHA=0.75;                                      % Water

% 3. Define FE geometry using automatic mesh-generator
L1=250; L2=0; L3=10; L4=10;                        % lengths, in ft
elA=0; elB=300; elC=300; elD=300; elWL=300;        % elevations, in ft
NBASE=11;                                         
ft=1.0;                                            % Conversion factor to ft

% 4 Define dynamic response parameters
NEV=12; NEXP=12; DT=0.01; 

% 5. Define EQ ground motion data
IHV=0; NUMREC=3000; dt=0.01; SFAC=-1; 
hName='Taft_horz.txt'; hNumHead=1;

%% CREATE INPUT FILE

% Create finite element idealization
[COORD Element WL Spacing NUMNP NUMEL NBASE, ...
 NPP WatNodes BaseNodes] = PRE_createMesh(L1,L2,L3,L4, ...
 elA,elB,elC,elD,elWL,NBASE,ft);

% Create earthquake array
[EQArrayH EQArrayV] = PRE_createEQArray(IHV, NUMREC, dt, SFAC, hName, hNumHead);

% Create input file
PRE_writeInput(IRES,ICOMB,IGRAV,IRIG,PSP,EC,POISC,DENSC,DAMPC, ...
 EF,DENSF,DAMPF,ALPHA,NUMNP,NUMEL,NBASE,Spacing,WL,NPP,COORD,Element, ...
 WatNodes,BaseNodes,NEV,NEXP,DT,IHV,NUMREC,dt,EQArrayH,EQArrayV);

%% RUN EAGD-84
RUN_E1A

%% READ OUTPUT TO WORKSPACE
clear all;

% Read output file
[NUMNP NUMEL NBASE COORD Element Post] = POST_readOutput;

% Read fort.3 file
[NUMNP NUMEL Post] = POST_readFort3(Post);

%% PERFORM POST PROCESSING

% Print mesh properties to txt file
Print_MeshProp(NUMNP,NUMEL,NBASE)

% Print natural frequencies to txt file
Print_Frequencies(Post);

% Plot first four mode shapes of dam-foundation system (not saved as
% files!)
for modeNum=1:4;
    Plot_Modeshape(COORD,Element,Post,NUMEL,modeNum);
end

% Plot displacement response histories for nodes 1, 144 and 243
DOFnum = [1 2 287 288 485 486]; % hor and vert DOFs corresponding to nodes

ft=12; cnt=1; gcf=figure;
for DOF = DOFnum
    subplot(3,2,cnt);
    Plot_Disp(DOF,Post,ft)
    axis([0 20 -1 1]); title(['DOF',num2str(DOF)]);
    cnt=cnt+1;
end
print(gcf,'EX1 Displacement Response.tif','-dtiff');


% Plot envelope values of maximum principal stresses
S = Post.PrinStrOA(:,2); 
ft=1; psi=1; % unit conversion
type = 2; % 1=B/W, 2=Color
gcf = Plot_Contour(S,Element,COORD,NUMNP,NUMEL,ft,psi,type);
print(gcf,'EX1 Maximum Principal Stress Envelopes.tif','-dtiff');


% Plot stress distribution when maximum principal stress occurs at the u/s
% heel
tM = Post.PrinStrOA(211,1); DT = Post.Displacement.t(2) - Post.Displacement.t(1);
loc = round(tM/DT+1);
S = Post.Stress{4}(:,loc);
type = 2; % 1=B/W, 2=Color
gcf = Plot_Contour(S,Element,COORD,NUMNP,NUMEL,ft,psi,type);
print(gcf,'EX1 Distribution Max Stress Upstream.tif','-dtiff');


% Move files to output directory
Cur_Dir = cd;
dirName = '\Analysis Results Examples\';
if isdir([Cur_Dir dirName])==0; mkdir([Cur_Dir dirName]); end
movefile('EX1 Displacement Response.tif','Analysis Results Examples\');
movefile('EX1 Maximum Principal Stress Envelopes.tif','Analysis Results Examples\');
movefile('EX1 Distribution Max Stress Upstream.tif','Analysis Results Examples\');
movefile('Natural Vibration Frequencies.txt','Analysis Results Examples\EX1 Natural Vibration Frequencies.txt');
movefile('FEM Properties.txt','Analysis Results Examples\EX1 FEM properties.txt');

% Delete FORTRAN files
if exist('fort.1','file') == 2; delete('fort.1'); end
if exist('fort.2','file') == 2; delete('fort.2'); end
if exist('fort.10','file') == 2; delete('fort.10'); end
if exist('fort.15','file') == 2; delete('fort.15'); end
if exist('fort.90','file') == 2; delete('fort.90'); end