%-------------------------------------------------------------------------%
% EXAMPLE RECOMPUTING RESULTS PRESENTED IN EERC 84/11, I.E., THE 
% ORIGNIAL EAGD-84 REPORT BY FENVES AND CHOPRA.
% 
% NOTE: DIFFERENT MESH, AND SLIGHTLY DIFFERENT GEOMETRY IS USED, HENCE
% THERE ARE MINOR DIFFERENCES IN THE COMUTED RESPONSE.
%-------------------------------------------------------------------------%
clc; clear all; close all

%% DEFINE INPUT

% 1. Define control parameters
IGRAV = 1;              % Perform static analysis
IRES = 0;               % Compute dynamic response
ICOMB = 1;              % Combine dyn. resp. with static loads
IRIG = 0;               % Foundation is flexible
PSP = 0.0;              % Dam and found. are in plane stress

% 2. Define material properties for Pine Flat Dam
% Dam
EC=4.68e5; DENSC=4.813665e-3; POISC=0.20; DAMPC=0.1;             
% Foundation
EF=4.68e5; DENSF=5.124224e-3; DAMPF=0.1; 
% Water
ALPHA=0.5;

% 3. Define FE geometry using automatic mesh-generator
L1=314.3; L2=16.75; L3=32.75; L4=32;                % in ft
elA=570; elB=930; elC=970; elD=910; elWL=951;       % in ft
NBASE = 11;
ft=1.0;                 % Conversion factor, units are in ft.

% 4 Define dynamic response parameters
NEV=12;                 % Number of Ritz vectors
NEXP=12;                % FFT parameter
DT = 0.01;              % Time step for computing response history

% 5. Define EQ ground motion data

IHV=2;                  % Response due to both hor&ver ground motion
NUMREC=3000;            % Number of records in files (only first 1500 included)
dt=0.01;                % Time-step of records
SFAC=-1;                % Scale factor for records
hName='Taft_horz.txt'; hNumHead=1;
vName='Taft_vert.txt'; vNumHead=1;

%% CREATE INPUT FILE

% Create finite element idealization
[COORD Element WL Spacing NUMNP NUMEL NBASE, ...
 NPP WatNodes BaseNodes] = PRE_createMesh(L1,L2,L3, ...
 L4,elA,elB,elC,elD,elWL,NBASE,ft);

% Create earthquake array
[EQArrayH EQArrayV] = PRE_createEQArray(IHV, NUMREC, dt, SFAC, hName, hNumHead, vName, vNumHead);

% Create input file
PRE_writeInput(IRES,ICOMB,IGRAV,IRIG,PSP,EC,POISC,DENSC,DAMPC, ...
 EF,DENSF,DAMPF,ALPHA,NUMNP,NUMEL,NBASE,Spacing,WL,NPP,COORD,Element, ...
 WatNodes,BaseNodes,NEV,NEXP,DT,IHV,NUMREC,dt,EQArrayH,EQArrayV);

%% RUN EAGD-84
RUN_E1A

%% READ OUTPUT TO WORKSPACE
clear all;

% Read output file
[NUMNP NUMEL NBASE COORD Element Post] = POST_readOutput;

% Read fort.3 file
[NUMNP NUMEL Post] = POST_readFort3(Post);

%% PERFORM POST PROCESSING

% Plot mesh
Plot_Mesh(NUMEL,COORD,Element,0)

% Plot displacement response histories for nodes 1, 166 and 276
DOFnum = [1 2 331 332 551 552]; % hor and vert DOFs corresponding to nodes

ft=12; 
cnt=1; gcf=figure;
for DOF = DOFnum
    subplot(3,2,cnt);
    Plot_Disp(DOF,Post,ft)
    title(['DOF ',num2str(DOF)]);
    axis([0 15 -2 2])
    cnt=cnt+1;
end
print(gcf,'EX2 Displacement Response.tif','-dtiff');

% Plot envelope values of maximum principal stresses
S = Post.PrinStrOA(:,2); 
ft=1; psi=1; % unit conversion
type = 1; % 1=B/W, 2=Color
gcf = Plot_Contour(S,Element,COORD,NUMNP,NUMEL,ft,psi,type);
print(gcf,'EX2 Maximum Principal Stress Envelopes.tif','-dtiff');

% Move files to output directory
Cur_Dir = cd;
dirName = '\Analysis Results Examples\';
if isdir([Cur_Dir dirName])==0; mkdir([Cur_Dir dirName]); end
movefile('EX2 Displacement Response.tif','Analysis Results Examples\');
movefile('EX2 Maximum Principal Stress Envelopes.tif','Analysis Results Examples\');

% Delete FORTRAN files
if exist('fort.1','file') == 2; delete('fort.1'); end
if exist('fort.2','file') == 2; delete('fort.2'); end
if exist('fort.10','file') == 2; delete('fort.10'); end
if exist('fort.15','file') == 2; delete('fort.15'); end
if exist('fort.90','file') == 2; delete('fort.90'); end