function [NUMNP NUMEL Post] = POST_readFort3(Post)
%-------------------------------------------------------------------------%
% Function to read fort.3 binary output file
%-------------------------------------------------------------------------%
%
% Programming by Arnkjell Loekke
% UCB / NTNU 2013
% email: lokke@stud.ntnu.no
%
%-------------------------------------------------------------------------%
% INPUT
% Post = data structure initiated by function Post_readOutput
%
%-------------------------------------------------------------------------%
% OUTPUT
% NUMNP = number of nodal points in discretization
% NUMEL = number of elements in discretization
% NEV = number of Ritz Vectors used (=gen. coordinates)
% DT = time increment
% NUMINC = number of total time increments
% Post = data structure containing output. Stresses for each element and 
%        displacements at every nodal point are saved at every time step 
%        as:
%     Post.Stress{1} = Sxx (horizontal)
%     Post.Stress{2} = Syy (vertical)
%     Post.Stress{3} = Sxy (shear) 
%     Post.Stress{4} = S11 (max principal) 
%     Post.Stress{5} = S22 (min principal)
%     Post.Displacement.U = displacements values for each nodal point
%     Post.Displacement.t = time values
%
%-------------------------------------------------------------------------%

% Check that file exists
if exist('fort.3','file') ~= 2 
    errordlg('fort.3 file not found in directory'); 
    error(''); 
end

% Open file and read header contents:
fid=fopen('fort.3');
dum=fread(fid, 1, 'int32');
NUMNP=fread(fid, 1, 'int32');
NUMEL=fread(fid, 1, 'int32');
NEV=fread(fid, 1, 'int32');
NUMINC=fread(fid, 1, 'int32');
DT=fread(fid, 1, 'double');

% Initialize vectors and matrices
Time=(0:DT:DT*(NUMINC-1));
Disp=zeros(NUMINC,2*NUMNP+1);
S=zeros(NUMINC,3*NUMEL+1);

% Read displacement and stress components
for n=1:NUMINC
    Disp(n,:)=fread(fid,2*NUMNP+1, 'double');
    S(n,:)=fread(fid,3*NUMEL+1, 'double');
end

% Sort data into correct output format
Disp=Disp(:,2:end);
Sxx=S(:,2:3:end);
Syy=S(:,3:3:end);
Sxy=S(:,4:3:end);

% Compute principal stresses
cc = (Sxx+Syy)/2;
bb = (Sxx-Syy)/2;
cr = sqrt(bb.^2+Sxy.^2);
ang = 90/pi * atan(Sxy./bb);
Sig1=cc+cr; Sig2=cc-cr;

% Save output to data structure
Post.Stress{1} = Sxx';
Post.Stress{2} = Syy';
Post.Stress{3} = Sxy';
Post.Stress{4} = Sig1';
Post.Stress{5} = Sig2';
Post.Displacement.U = Disp';
Post.Displacement.t = Time;

% Close file
fclose(fid);