function [NUMNP NUMEL NBASE COORD Element Post] = POST_readOutput
%-------------------------------------------------------------------------%
% Function to read output file
%-------------------------------------------------------------------------%
%
% Programming by Arnkjell Loekke
% UCB / NTNU 2013
% email: lokke@stud.ntnu.no
% 
% Based on scripts provided by Baris Binici at the 
% Middle East Technical University (METU) 2013
%
%-------------------------------------------------------------------------%
% INPUT
% (none)
%
%-------------------------------------------------------------------------%
% OUTPUT
% NUMNP   = number of nodal points in discretization
% NUMEL   = number of elements in discretization
% NBASE   = number of nodal points along base
% COORD   = coordinates of nodal points
% Element = connectivity of elements
% Post    = data structure, containing:
%     Post.Static.Load         = Hydrostatic load on dam
%     Post.Static.Disp         = Displacements due to static loads
%     Post.Static.Stress       = Stresses due to static loads
%     Post.Vibration.Freq      = Vibration frequencies of dam/dam-found system
%     Post.Vibration.Modeshape = Mode shapes of vibration
%     Post.Vibration.FRF_Omega = omega-values for FRF
%     Post.Vibration.FRF_Horz  = Abs. value of horizontal FRF
%     Post.Vibration.FRF_Vert  = Abs. value of vertical   FRF
%     Post.PrinStrOA           = Peak value of principal stresses and their
%                                time of occurence
%
%-------------------------------------------------------------------------%

% Check that file exists
if exist('output','file') ~= 2 
    errordlg('Output file not found in directory'); 
    error('');
end

% Open file and initialize first line
fid = fopen('output','r');
Line = fgetl(fid);

% Read control information
whcheck = 0;
while feof(fid) ~= 1 && whcheck ~= 7
    if strfind(Line,'number of nodal points') == 2;
        NUMNP = str2num(Line(51:54));
        Line = fgetl(fid);
        NUMEL=str2num(Line(51:54));
        whcheck = whcheck + 1;
    end
    if strfind(Line,'number of base connection nodes at foundation') == 2;
        NBASE = cell2mat(textscan(Line,'%*s %*s %*s %*s %*s %*s %*s %d'));
        whcheck = whcheck + 1;
    end
    if strfind(Line,'number of generalized coordinates') == 2;
        NEV = cell2mat(textscan(Line,'%*s %*s %*s %*s %*s %d'));
        whcheck = whcheck + 1;
    end
    if strfind(Line,'number of upstream nodes touching water') == 2;
        NPP = cell2mat(textscan(Line,'%*s %*s %*s %*s %*s %*s %d'));
        whcheck = whcheck + 1;
    end
    if strfind(Line,'code for static analysis') == 2;
        IGRAV = cell2mat(textscan(Line,'%*s %*s %*s %*s %d'));
        whcheck = whcheck + 1;
    end
    if strfind(Line,'code for plane stress/strain model') == 2;
        PSP=cell2mat(textscan(Line,'%*s %*s %*s %*s %*s %f'));
        whcheck = whcheck + 1;
    end
    if strfind(Line,'code for dynamic analysis') == 2;
        IRES=cell2mat(textscan(Line,'%*s %*s %*s %*s %f'));
        whcheck = whcheck + 1;
    end
    Line = fgetl(fid);
end

% Read nodal coordinates
whcheck = 0;
while feof(fid) ~= 1 && whcheck ~= 1
    if strfind(Line,'nodal point specification') == 2;
        Line = fgetl(fid); Line = fgetl(fid); Line = fgetl(fid);
        Line = fgetl(fid); Line = fgetl(fid); Line = fgetl(fid);
        for i=1:1:NUMNP
            COORD(i,1)=cell2mat(textscan(Line,'%*d %*d %f %*d'));
            COORD(i,2)=cell2mat(textscan(Line,'%*d %*d %*d %f'));
            Line = fgetl(fid);
        end
        whcheck = 1;
    end
    Line = fgetl(fid);
end

% Read element specifications
whcheck = 0;
while feof(fid) ~= 1 && whcheck ~= 1
    if strfind(Line,'element specification') == 2;
        Line = fgetl(fid); Line = fgetl(fid); Line = fgetl(fid);
        Line = fgetl(fid); Line = fgetl(fid); Line = fgetl(fid);
        for i=1:1:NUMEL
            Element(i,:)=cell2mat(textscan(Line,'%*f %f %f %f %f %*f'));
            Line = fgetl(fid);
        end
        whcheck = 1;
    end
    Line = fgetl(fid);
end

% Read hydrostatic forces (in lb),
whcheck = 0; 
while feof(fid) ~= 1 && whcheck ~= 1 && NPP~=0
    if strfind(Line,'equivalent nodal forces due to hydrostatic pressure') == 2;
        Line = fgetl(fid); Line = fgetl(fid);
        Line = fgetl(fid);Line = fgetl(fid);
        for i=1:1:NPP
            Post.Static.Load(i,:)=cell2mat(textscan(Line,'%f %f %f'));
            Line = fgetl(fid);
        end
        whcheck = 1;
    end
    Line = fgetl(fid);
end
if whcheck==0; Post.Static.Load=-1; end

% Read displ. and stresses due to static loads
whcheck = 0;
if IGRAV == 1
    while feof(fid) ~= 1 && whcheck ~= 1
        if strfind(Line,'displacements due to static loads') == 2;
            Line = fgetl(fid); Line = fgetl(fid);
            Line = fgetl(fid); Line = fgetl(fid);
            for i=1:1:NUMNP
                Post.Static.Disp(i,:)=cell2mat(textscan(Line,'%*f %f %f'));
                Line = fgetl(fid);
            end
            whcheck = 1;
        end
        Line = fgetl(fid);
    end
    whcheck = 0;
    while feof(fid) ~= 1 && whcheck ~= 1
        if strfind(Line,'element stresses in psi') == 2;
            Line = fgetl(fid); Line = fgetl(fid);
            Line = fgetl(fid);
            for i=1:1:NUMEL
                Post.Static.Stress(i,1:3)=cell2mat(textscan(Line,'%*f %*f %*f %f %f %f %*f %*f %*f'));
                Post.Static.Stress(i,4:5)=cell2mat(textscan(Line,'%*f %*f %*f %*f %*f %*f %f %f %*f'));
                Line = fgetl(fid);
            end
            whcheck = 1;
        end
        Line = fgetl(fid);
    end
else
    Post.Static.Disp=-1; Post.Static.Stress=-1;
end

% Read natural vibration frequencies (rad/sec) and eigth first mode shapes of empty dam
whcheck = 0;
while feof(fid) ~= 1 && whcheck ~= 1
    if strfind(Line,'frequencies (rad/sec) of dam with reservoir empty') == 2;
        Line = fgetl(fid); Line = fgetl(fid);
        Line = fgetl(fid); Line = fgetl(fid);
        for i=1:1:NEV
            Post.Vibration.Freq(i,1)=cell2mat(textscan(Line,'%*s %*s %f'));
            Line = fgetl(fid);
        end   
        Line = fgetl(fid); Line = fgetl(fid);
        Line = fgetl(fid); Line = fgetl(fid);
        Line = fgetl(fid);
        for i=1:2*NUMNP
           Post.Vibration.Modeshape(i,:)=cell2mat(textscan(Line,'%f'));
            Line = fgetl(fid);
        end       
        whcheck = 1;
    end
    Line = fgetl(fid);
end

% Exit if dynamic response has not been computed
if IRES==1; Post.IRES=1; return; end

% Read frequency response parameters
whcheck = 0;
while feof(fid) ~= 1 && whcheck ~= 3
    if strfind(Line,'code for ground motion component') == 3;
        IHV = cell2mat(textscan(Line,'%*d %*s %*s %*s %*s %*s %*s %f'));
        whcheck = whcheck + 1;
    end
    if strfind(Line,'number of points for frequency response') == 3;
        N=cell2mat(textscan(Line,'%*d %*s %*s %*s %*s %*s %*s %f'));
        if size(N,1)==0; N=str2num(Line(end-4:end)); end
        NEXP=log2(N);
        whcheck = whcheck + 1;
    end
    if strfind(Line,'time step for response') == 3;
        DT=cell2mat(textscan(Line,'%*d %*s %*s %*s %*s %f %*s'));
        whcheck = whcheck + 1;
    end
    Line = fgetl(fid);
end


% Read frequency response functions
whcheck = 0;
while feof(fid) ~= 1 && whcheck ~= 1
    if strfind(Line,'absolute value of frequency responses for generalized accelerations of the dam') == 2;
        Line = fgetl(fid); Line = fgetl(fid); Line = fgetl(fid);
        Line = fgetl(fid); Line = fgetl(fid); Line = fgetl(fid);
        Line = fgetl(fid); 
        if IHV== 2; numVAL = min(2*NEV+1,13); else numVAL = min(NEV+1,7); end
        if numVAL>7; Line = fgetl(fid); end
        for i=1:N
            if length(cell2mat(textscan(Line,'%f',numVAL)))==numVAL
                dumVal(i,1:numVAL) = cell2mat(textscan(Line,'%f',numVAL));
            end
            Line = fgetl(fid);
        end
        Post.Vibration.FRF_Omega = dumVal(:,1);
        numROW = min(NEV,6);
        if IHV == 0
            Post.Vibration.FRF_Horz = dumVal(:,2:numROW+1);
            Post.Vibration.FRF_Vert = -1;
        elseif IHV == 1
            Post.Vibration.FRF_Vert = dumVal(:,2:numROW+1);
            Post.Vibration.FRF_Horz = -1;
        elseif IHV == 2
            Post.Vibration.FRF_Horz = dumVal(:,2:numROW+1);
            Post.Vibration.FRF_Vert = dumVal(:,numROW+2:end);
        end
        whcheck = 1;
    end
    Line = fgetl(fid);
end

% Read EQ ground motion data
whcheck=0;
if IHV == 0
    while feof(fid) ~= 1 && whcheck ~= 1
        if strfind(Line,'number of ordinates for horizontal earthquake data') == 3;
            NUMREC=cell2mat(textscan(Line,'%*d %*s %*s %*s %*s %*s %*s %*s %f'));
            whcheck = 1;
        end
        Line = fgetl(fid);
    end
elseif IHV == 1
    while feof(fid) ~= 1 && whcheck ~= 1
        if strfind(Line,'number of ordinates for   vertical earthquake data') == 3;
            NUMREC=cell2mat(textscan(Line,'%*d %*s %*s %*s %*s %*s %*s %*s %f'));
            whcheck = 1;
        end
        Line = fgetl(fid);
    end
elseif IHV == 2
    while feof(fid) ~= 1 && whcheck ~= 1
        if strfind(Line,'number of ordinates for horizontal earthquake data') == 3;
            NUMREC=cell2mat(textscan(Line,'%*d %*s %*s %*s %*s %*s %*s %*s %f'));
            whcheck = 1;
        end
        Line = fgetl(fid);
    end
end
        
% Read duration of response
whcheck=0;
while feof(fid) ~= 1 && whcheck ~= 1
    if strfind(Line,'time duration of response') == 3;
        DUR=cell2mat(textscan(Line,'%*d %*s %*s %*s %*s %f'));
        whcheck = 1;
    end
    Line = fgetl(fid);
end

% Read print intervals
whcheck = 0;
while feof(fid) ~= 1 && whcheck ~= 1
    if strfind(Line,'number of print intervals') == 3;
        NPRINT=cell2mat(textscan(Line,'%*d %*s %*s %*s %*s %f'));
        whcheck = 1;
    end
    Line = fgetl(fid);
end

% Read overall maximum & minimum stresses
whcheck = 0;
fseek(fid, -90000, 'eof'); % position file
Line=fgetl(fid); Line=fgetl(fid);

while feof(fid) ~= 1 && whcheck ~= 1
    if strfind(Line,'element        time  max.stress        time  min.stress') == 4;
        Line = fgetl(fid); Line = fgetl(fid); Line = fgetl(fid);
        for i=1:1:NUMEL
            Post.PrinStrOA(i,:)=cell2mat(textscan(Line,'%*f %f %f %f %f'));
            Line = fgetl(fid);
        end
        whcheck = 1;
    end
    Line = fgetl(fid);
end

% Close file
fclose(fid);
