function [EQArrayH EQArrayV] = PRE_createEQArray(IHV, NUMREC, dt, SFAC, varargin)
%-------------------------------------------------------------------------%
% Function to write EQDATA array
%-------------------------------------------------------------------------%
% 
% INPUT
% IHV = Code for hor/vert. ground motion
% NUMREC = Number of records in files
% dt = time step of records
% SFAC = Scale factor for records
% varargin: 
%   hName = name of horizontal acceleration file
%   hNumHead = number of header lines in file
%   vName = name of vertical acceleration file
%   vNumHead = number of header lines in file
%
%-------------------------------------------------------------------------%
% OUTPUT
% EQArrayH
% EQArrayV
%-------------------------------------------------------------------------%
%
% Programming by Arnkjell Loekke
% UCB / NTNU 2013
% email: lokke@stud.ntnu.no
%
%-------------------------------------------------------------------------%

% Check input
if length(varargin) < 2; error('Earthquake ground motion file not specified'); end
if IHV==2 && length(varargin)~=4; error('Not sufficient input for both horizontal and vertical ground motion'); end

% Set up vectors and EQArrays
norow=floor(NUMREC/6);

% Horizontal ground motion
if IHV==0 || IHV ==2
     
    % Initialize
    fclose all; clear EQ
    hName = varargin{1};
    numhead=varargin{2};
    
    % Read file and position
    fid = fopen(hName,'r'); 
    line = fgetl(fid);
    for n=1:numhead; line = fgetl(fid); end
    
    % Set parameters
    numcol = length(cell2mat(textscan(line,'%f')));
    T=0:dt:(NUMREC-1)*dt;
    nr1=floor(NUMREC/numcol);
    
    % Extract values
    n=0;
    while ~feof(fid) && n+1<=nr1
        dum = cell2mat(textscan(line,'%f'));
        EQ(numcol*n+1 : numcol*(n+1)) = dum;
        n=n+1;    
        line=fgetl(fid);
    end
    
    % Last line
    nex2=NUMREC-size(EQ,2);
    dum = cell2mat(textscan(line,'%f'));
    
    % Check bounds
    if nex2 > length(dum)
        errordlg('Not enough data points in text file, aborting...')
    end
    EQ = [EQ'; dum(1:nex2)];
    
    % Scale with scale factor
    EQ = EQ*SFAC;
    
    % Modify file to fit EAGD input
    EQhor=[T' EQ];
    for i=1:NUMREC
        EQdum(2*i-1:2*i)=[EQhor(i,1) EQhor(i,2)];
    end
    
    % Modify last entries
    nex=mod(NUMREC,6);  
    EQArrayH = reshape(EQdum(1:norow*12),12,norow)';
    if nex~= 0
        EQArrayH = [EQArrayH; zeros(1,12)];
        EQArrayH(norow+1,1:2*nex)=EQdum(norow*12+1:end);
    end
end
    
% Vertical ground motion
if IHV==1 || IHV ==2
    % Initialize
    fclose all; clear EQ
    if IHV==1 && length(varargin) == 2;
        vName = varargin{1}; numhead=varargin{2};
    else      
        vName = varargin{3}; numhead=varargin{4};
    end
        
    % Read file and position
    fid = fopen(vName,'r');
    line = fgetl(fid);
    for n=1:numhead; line = fgetl(fid); end
    
    % Set parameters
    numcol = length(cell2mat(textscan(line,'%f')));
    T=0:dt:(NUMREC-1)*dt;
    nr1=floor(NUMREC/numcol);
    
    % Extract values
    n=0;
    while ~feof(fid) && n+1<=nr1
        dum = cell2mat(textscan(line,'%f'));
        EQ(numcol*n+1 : numcol*(n+1)) = dum;
        n=n+1;    
        line=fgetl(fid);
    end
    
    % Last line
    nex2=NUMREC-size(EQ,2);
    dum = cell2mat(textscan(line,'%f'));
    
    % Check bounds
    if nex2 > length(dum)
        errordlg('Not enough data points in text file, aborting...')
    end
    
    EQ = [EQ'; dum(1:nex2)];

    % Scale with scale factor
    EQ = EQ*SFAC;
    
    % Modify file to fit EAGD input
    EQver=[T' EQ];
    for i=1:NUMREC
        EQdum(2*i-1:2*i)=[EQver(i,1) EQver(i,2)];
    end
    
    % Modify last entries
    nex=mod(NUMREC,6); 
    EQArrayV = reshape(EQdum(1:norow*12),12,norow)';
    if nex~=0
        EQArrayV = [EQArrayV; zeros(1,12)];
        EQArrayV(norow+1,1:2*nex)=EQdum(norow*12+1:end);
    end
end

% Set EQarrays to -1 if applicable
if IHV==0; 
    EQArrayV=-1;
elseif IHV==1; 
    EQArrayH=-1; 
end

fclose(fid);
