function [COORD Element WL Spacing NUMNP NUMEL NBASE, ...
          NPP WatNodes BaseNodes] = PRE_createMesh(L1m,L2m,L3m, ...
          L4m,elA,elB,elC,elD,elWL,NBASE,ft)
%-------------------------------------------------------------------------%
% Function to create mesh
%-------------------------------------------------------------------------%
%
% Programming by Arnkjell Loekke
% UCB / NTNU 2013
% email: lokke@stud.ntnu.no
%
% based on scripts provided by Baris Banici at the 
% Middle East Technical University (METU) in 2013
%
%-------------------------------------------------------------------------%
% INPUT
% (see users manual)
%
%-------------------------------------------------------------------------%
% OUTPUT
% COORD = Coordinates of nodal points
% Element = Element connectivity table
% WL = height of water line
% Spacing = Spacing of base nodal points
% NUMNP = Number of nodal points
% NUMEL = Number of elements
% NBASE = number of base nodal points
% NPP = Number of "wet" nodal points 
% WatNodes = Nodes touching water
% BaseNodes = Nodes along base
%


%% INITIALIZE AND SET UP VALUES TO BE USED

% Compute lenghts and heigts
L5m = L1m - (L2m+L3m); L6m = L3m-L4m;
H1m = elB - elA; H2m = elC-elD;
H3m = elD-elA; 
HWm = max(elWL-elA,0);
Hdm = elC-elA;

% Compute flags
skip1=(elA==elB);
skip2=(elD==elC);
skip3=(elA==elD);

% Compute slopes
m1=0; m2=0; m3=0;
if ~skip1; m1 = L2m / (elB-elA); end
if ~skip2; m2 = L6m / (elC-elD); end
if ~skip3; m3 = L5m / (elD-elA); end

% Conversion of units, if applicable
H1=H1m*ft ;                                           %Height 1
H2=H2m*ft ;                                           %Height 2
H3=H3m*ft ;                                           %Height 3
Hd=Hdm*ft ;                                           %Height of dam
WL=HWm*ft ;                                           %Free Surface Water Height
L4=L4m*ft ;                                           %Crest length in feet
Base=L1m*ft;                                          %Base Length in feet
L2=L2m*ft;                                            %Length of other regions

% Define discretization parameters
NoBaseDiv = NBASE-1;
Spacing=Base/NoBaseDiv;                                %Equal Spacing Between Base Nodal Points

%% GENERATE NODES IN BLOCKS
node=1;

% Inititalize parameters for mesh control
xcur=L2; basecur=L4; baseadd1=0;
heightcur=Hd; cont=1; NoUnique=-1;
aspct = 1.75;
minhgt = Hd*0.02;
maxhgt = Hd*0.1;

while cont
    hsub = aspct*basecur/NBASE;
    if NoUnique==-1; 
        hsub=0;
    else
        hsub=max(min(hsub,maxhgt),minhgt);
    end
    heightcur = heightcur - hsub;
    
    % Check lower bound
    if heightcur<0 || abs(heightcur)<=0.4*Spacing; heightcur=0; cont=0;
    elseif abs(heightcur)<=Hd*0.15 && abs(heightcur)<= 2*Spacing; heightcur = y1(node-1)*0.5; 
    end
    
    % Create length and width of current element row
    if heightcur<H1; 
        xcur=L2-(H1-heightcur)*m1;
        baseadd1=(H1-heightcur)*m1;
    end
    if heightcur>H3
        baseadd2=(Hd-heightcur)*m2;
        basecur=L4+baseadd1+baseadd2;
    else
        baseadd3=H2*m2+(H3-heightcur)*m3;
        basecur=L4+baseadd1+baseadd3;
    end
    
    % Create nodal points
    for j=1:1:NBASE
        n1(node)=node                           ;
        x1(node)=xcur+(j-1)*basecur/NoBaseDiv   ;
        y1(node)=heightcur                      ;
        node=node+1                             ;
    end
    NoUnique=NoUnique+1;
end

% Reshape into data structure
COORD=[ n1' x1' y1' ];   

% Define number of elements and nodal points
NUMNP=(NoBaseDiv+1)*(NoUnique+1);           
NUMEL=NoBaseDiv*NoUnique;                

%% GENERATE ELEMENT CONNECTIVITY
count1=1  ;
count2=1  ;
Element=zeros(NUMEL,4);
for k=1:NoUnique
    for l=1:1:NoBaseDiv
        Element(count1,1)=count2 ;
        Element(count1,2)=count2+NoBaseDiv+1 ;
        Element(count1,3)=count2+NoBaseDiv+2 ;
        Element(count1,4)=count2+1   ;
        count1=count1+1 ;
        count2=count2+1 ;
        if l==NoBaseDiv  ; count2=count2+1 ; end
    end
end
Element=[ (1:NUMEL)' Element];

%% GENERATE WATER AND BASE NODES

% Water nodes
USNodes=1:NoBaseDiv+1:(NoBaseDiv+1)*NoUnique+1 ;
WatNodes=USNodes(COORD(USNodes,3)<WL);
if any(WatNodes)
    NoWatNode = WatNodes(1) - (NoBaseDiv+1);
    if NoWatNode > 0; WatNodes = [NoWatNode WatNodes]; end
end
NPP = length(WatNodes); if NPP==1; NPP=0; end

% Base nodes
BaseNodes=(NoBaseDiv+1)*NoUnique+1:1:NUMNP ;

end
