function [NUMNP NUMEL NBASE WL NPP Spacing WatNodes BaseNodes ... 
          COORD Element] = PRE_readMesh(NUMNP,NUMEL,NBASE,Spacing,WL,NPP,fName)
%-------------------------------------------------------------------------%
% Function to read user mesh input file
%-------------------------------------------------------------------------%
%
% Programming by Arnkjell Loekke
% UCB / NTNU 2013
% email: lokke@stud.ntnu.no
%
%-------------------------------------------------------------------------%
% INPUT
% NUMNP = Number of nodal points in FE mesh
% NUMEL = Number of elements in FE mesh
% NBASE = Number of nodal points at the dam base
% Spacing = Spacing of the nodal points at the dam base
% WL = Depth of water in reservoir
% NPP = Number of nodal points in touch with water
% fName = string for mesh input file
%
%-------------------------------------------------------------------------%
% OUTPUT
% NUMNP = Number of nodal points in FE mesh
% NUMEL = Number of elements in FE mesh
% NBASE = Number of nodal points at the dam base
% WL = Depth of water in reservoir
% NPP = Number of nodal points in touch with water
% Spacing = Spacing of the nodal points at the dam base
% WatNodes = Nodal points in touch with water
% BaseNodes = Nodal points at the dam base
% COORD = Matrix containing nodal point coordinates
% Element = Matrix containing element connectivity
%
%-------------------------------------------------------------------------%

% Check that file exists
if exist(fName,'file') ~= 2 
    errordlg('mesh file not found in directory'); 
    error('mesh file not found in directory');
end

% Open file and initialize first line
fclose all;
fid = fopen(fName,'r');
Line = fgetl(fid);

% Read nodal points
for nod = 1:NUMNP
    dum = str2num(Line);
    COORD(nod,1) = dum(1);
    if length(dum) == 3
        COORD(nod,2) = dum(2);
        COORD(nod,3) = dum(3);
    else
        COORD(nod,2) = dum(3);
        COORD(nod,3) = dum(4);  
    end
    Line = fgetl(fid);
end

% Read element connectivity
cnt=1; elMax=1;
while elMax < NUMEL
    dum = str2num(Line);
    Element(cnt,1) = dum(1);
    Element(cnt,2) = dum(2);
    Element(cnt,3) = dum(3);
    Element(cnt,4) = dum(4);
    Element(cnt,5) = dum(5);
    Element(cnt,6) = 1; % NOTE: only 1 material supported
    elMax = Element(cnt,1);
    cnt=cnt+1;
    Line = fgetl(fid);
end

% Read Water Nodes
WatNodes=0;
if NPP~= 0
    WatNodes = cell2mat(textscan(Line,'%f'))';
    NPPremain = NPP - length(WatNodes);
    while NPPremain > 0
        Line =fgetl(fid);
        WatNodes = [WatNodes cell2mat(textscan(Line,'%f'))']; 
        NPPremain = NPP - length(WatNodes);
    end
    Line =fgetl(fid);
    if WatNodes(1) == 0; WatNodes = WatNodes(2:end); end
end


% Read Base Nodes
BaseNodes=0;
if NBASE ~= 0 && Spacing~= 0
    BaseNodes = cell2mat(textscan(Line,'%f'))';
    NBASEremain = NBASE - length(BaseNodes);
    while NBASEremain > 0
        Line =fgetl(fid);
        BaseNodes = [BaseNodes cell2mat(textscan(Line,'%f'))']; 
        NBASEremain = NBASE - length(BaseNodes);
    end
end

% Close file
fclose all;
