function PRE_writeInput(IRES,ICOMB,IGRAV,IRIG,PSP,EC,POISC,DENSC,DAMPC, ...
         EF,DENSF,DAMPF,ALPHA,NUMNP,NUMEL,NBASE,Spacing,WL,NPP,COORD,Element, ...
         WatNodes,BaseNodes,NEV,NEXP,DT,IHV,NUMREC,dt,EQArrayH,EQArrayV)
%-------------------------------------------------------------------------%
% Function to create input file to be run with EAGD84
%-------------------------------------------------------------------------%
%
% Programming by Arnkjell Loekke
% UCB / NTNU 2013
% email: lokke@stud.ntnu.no
% 
% Based on scripts provided by Baris Binici at the 
% Middle East Technical University (METU) 2013
%
%-------------------------------------------------------------------------%
% INPUT
% (See user manual)
%
%-------------------------------------------------------------------------%
% OUTPUT
% correctly formatted EAGD-84 input file, 
% saved in the directory as: 'input' (without file extension)
%
%-------------------------------------------------------------------------%

% Define default (non-user changeable) parameters
IOPR=0;IOPP=1;IGEN=1;ISEL=0;
NUMMAT=1;NPRINT=100;     

% Check consitency of parameters
if ICOMB; IGRAV=1; end

% Open file
fclose all;
fid1 = fopen('input','wt');

% Write header, control parameters, foundation data, material properties
fprintf(fid1, ' DYNAMIC ANALYSIS OF A DAM SECTION \n');
fprintf(fid1, '%5i%5i%5i%5i%5i%10.2f%5i%5i%5.2f%5i%5i%5i%5i%5i \n', NUMNP, NUMEL, NUMMAT, NBASE, NEV, WL, NPP, IGRAV, PSP, IRES, IOPR, IOPP, IRIG, IGEN);
if (IRIG==0); fprintf(fid1, '%10.3e%10.5f%10.5f%10.5f \n',EF, DENSF, DAMPF, Spacing ); end
fprintf(fid1, '%5i%10.3e%10.3f%10.5f \n',NUMMAT, EC, POISC, DENSC );

% Write nodal coordinates and element definition
% NOTE: ARBITRARY BOUNDARY CONDITIONS NOT SUPPORTED
for i=1:1:NUMNP
    if (IRIG==1) && ( COORD(i,3)==min(COORD(:,3)) )
        bc=3.0 ;
    else
        bc=0.0 ;
    end
    fprintf(fid1, '%5i%5.1f%10.3f%10.3f \n',COORD(i,1), bc, COORD(i,2), COORD(i,3) );
end

% Write element connectivity
for i=1:1:size(Element,1)
    fprintf(fid1, '%5i%5i%5i%5i%5i%5i \n',Element(i,1), Element(i,2), Element(i,3), Element(i,4), Element(i,5), NUMMAT );
end

% Write upstream water nodes
leftno=NPP-15 ;
if (leftno>=1) ;
    fprintf(fid1, '%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i \n',0, WatNodes(1:15) );
    norows=ceil((NPP-15)/16) ;
    data=16 ;
    for i=1:1:norows
        if (i~=norows) ;
            fprintf(fid1, '%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i \n',WatNodes(data:data+15) );
            data=data+16  ;
        else
            for k=data:1:NPP
                fprintf(fid1, '%5i',WatNodes(data) );
                data=data+1 ;
            end
            fprintf(fid1, '\n');
        end
    end
elseif NPP>1
    fprintf(fid1, '%5i%5i',0, WatNodes(1) );
    for k=2:NPP
        fprintf(fid1, '%5i',WatNodes(k) );
    end
    fprintf(fid1, '\n');
end

% Write base nodes
if IRIG==0
    norows=ceil(NBASE/16) ;
    data=1;
    for i=1:1:norows
        if (i~=norows) ;
            fprintf(fid1, '%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i%5i \n',BaseNodes(data:data+15) );
            data=data+16 ;
        else
            for k=data:1:NBASE
                fprintf(fid1, '%5i',BaseNodes(data) );
                data=data+1 ;
            end
        end
    end
    fprintf(fid1, '\n');
end

% Write dynamic response parameters
fprintf(fid1, '%5i%5i%10.5f%10.5f%10.5f \n', IHV, NEXP, DT, ALPHA, DAMPC);

% Write EQ info
if IHV == 0
    HorzEQ=NUMREC ;
    VertEQ=0 ;
    TD=(HorzEQ)*dt ;
elseif IHV == 1
    HorzEQ=0 ;
    VertEQ=NUMREC ;
    TD=VertEQ*dt ;
elseif IHV == 2
    HorzEQ=NUMREC ;
    VertEQ=NUMREC ;
    TD=(HorzEQ)*dt ;
end
fprintf(fid1, '%5i%5i%10.5f \n', HorzEQ, VertEQ, TD);

% Write EQ time series with 3 or 4-decimal precision
if IHV == 0
    for i=1:1:length(EQArrayH)
        for j=2:2:12
            t=EQArrayH(i,j-1);
            num=EQArrayH(i,j); numc=num2str(num,'%7.4f');
            if num==0; str=['.0000'];
            elseif num>0; dec=numc(3:end); str=['.',dec];
            else dec=numc(4:end); str=['-.',dec]; end
            if abs(num)<1; fprintf(fid1,'%6.3f%6s',t,str);
            else fprintf(fid1,'%6.3f%6.3f',t,num); end
        end
        fprintf(fid1, '\n');
    end
elseif IHV == 1
    for i=1:1:length(EQArrayV)
        for j=2:2:12
            t=EQArrayV(i,j-1);
            num=EQArrayV(i,j); numc=num2str(num,'%7.4f');
            if num==0; str=['.0000'];
            elseif num>0; dec=numc(3:end); str=['.',dec];
            else dec=numc(4:end); str=['-.',dec]; end
            if abs(num)<1; fprintf(fid1,'%6.3f%6s',t,str);
            else fprintf(fid1,'%6.3f%6.3f',t,num); end
        end
        fprintf(fid1, '\n');
    end
elseif IHV == 2
    for i=1:1:length(EQArrayH)
        for j=2:2:12
            t=EQArrayH(i,j-1);
            num=EQArrayH(i,j); numc=num2str(num,'%7.4f');
            if num==0; str=['.0000'];
            elseif num>0; dec=numc(3:end); str=['.',dec];
            else dec=numc(4:end); str=['-.',dec]; end
            if abs(num)<1; fprintf(fid1,'%6.3f%6s',t,str);
            else fprintf(fid1,'%6.3f%6.3f',t,num); end
        end
        fprintf(fid1, '\n');
    end
    for i=1:1:length(EQArrayV)
        for j=2:2:12
            t=EQArrayV(i,j-1);
            num=EQArrayV(i,j); numc=num2str(num,'%7.4f');
            if num==0; str=['.0000'];
            elseif num>0; dec=numc(3:end); str=['.',dec];
            else dec=numc(4:end); str=['-.',dec]; end
            if abs(num)<1; fprintf(fid1,'%6.3f%6s',t,str);
            else fprintf(fid1,'%6.3f%6.3f',t,num); end
        end
        fprintf(fid1, '\n');
    end
end

% Write output needs
fprintf(fid1, '%5i%5i%5i \n', NPRINT,ICOMB,ISEL);

% Close file
fclose(fid1);
